@@ -28,7 +28,7 @@
 #include <limits>
 #include <sstream>
 
-#include "debug.h"
+#include "dbg.h"
 #include "msg.h"
 
 #include "str.h"
@@ -201,7 +201,7 @@ namespace str
         is >> v;
         if (is.fail() || !is.eof())
         {
-            throw exc(std::string("cannot convert '") + sanitize(s) + "' to " + name, EINVAL);
+            throw exc(std::string("Cannot convert '") + sanitize(s) + "' to " + name, EINVAL);
         }
         return v;
     }
@@ -231,8 +231,8 @@ namespace str
             /* Should never happen (out of memory or some invalid conversions).
              * We do not want to throw an exception because this function might
              * be called because of an exception. Inform the user instead. */
-            msg::err("FAILURE IN str::vasprintf().");
-            debug::crash();
+            msg::err("Failure in str::vasprintf().");
+            dbg::crash();
         }
         std::string s(cstr);
         free(cstr);
