@@ -24,7 +24,7 @@
 
 #include <cstring>
 
-#include "debug.h"
+#include "dbg.h"
 #include "msg.h"
 #include "opt.h"
 
@@ -44,7 +44,7 @@ int main(int argc, char *argv[])
     msg::set_level(msg::INF);
     msg::set_program_name(program_name);
     msg::set_columns_from_env();
-    debug::init_crashhandler();
+    dbg::init_crashhandler();
 
     /* Command line handling */
     std::vector<opt::option *> options;
@@ -221,7 +221,7 @@ int main(int argc, char *argv[])
     }
     if (crosstalk.value().size() != 1 && crosstalk.value().size() != 3)
     {
-        msg::err("invalid crosstalk levels");
+        msg::err("Invalid crosstalk levels");
         return 1;
     }
 
@@ -282,8 +282,8 @@ int main(int argc, char *argv[])
         init_data.input_mode = input::mode_from_name(input_mode.value(), &ok);
         if (!ok)
         {
-            msg::err("invalid input mode name");
-            debug::crash();
+            msg::err("Invalid input mode name");
+            dbg::crash();
         }
     }
     if (video_output_mode.value() == "equalizer")
@@ -311,8 +311,8 @@ int main(int argc, char *argv[])
         init_data.video_mode = video_output::mode_from_name(video_output_mode.value(), &ok);
         if (!ok)
         {
-            msg::err("invalid output mode name");
-            debug::crash();
+            msg::err("Invalid output mode name");
+            dbg::crash();
         }
     }
     init_data.video_state.parallax = parallax.value();
@@ -329,7 +329,7 @@ int main(int argc, char *argv[])
     init_data.benchmark = benchmark.value();
     if (init_data.benchmark)
     {
-        msg::inf("benchmark mode: audio and time synchronization disabled");
+        msg::inf("Benchmark mode: audio and time synchronization disabled");
     }
 
     int retval = 0;
@@ -341,7 +341,7 @@ int main(int argc, char *argv[])
 #if HAVE_LIBEQUALIZER
             player = new class player_equalizer(&argc, argv, equalizer_flat_screen);
 #else
-            throw exc("this version of Bino was compiled without support for Equalizer");
+            throw exc("This version of Bino was compiled without support for Equalizer");
 #endif
         }
         else if (arguments.size() == 0 || show_gui.value())
