@@ -144,8 +144,11 @@ in_out_widget::in_out_widget(QSettings *settings, QWidget *parent)
 {
     QGridLayout *layout0 = new QGridLayout;
     QLabel *input_label = new QLabel("Input:");
+    input_label->setToolTip(
+            "<p>Set the 3D layout type of your input file(s).</p>");
     layout0->addWidget(input_label, 0, 0);
     _input_combobox = new QComboBox(this);
+    _input_combobox->setToolTip(input_label->toolTip());
     _input_combobox->addItem("2D");
     _input_combobox->addItem("Separate streams");
     _input_combobox->addItem("Top/bottom");
@@ -157,15 +160,22 @@ in_out_widget::in_out_widget(QSettings *settings, QWidget *parent)
     layout0->addWidget(_input_combobox, 0, 1);
     layout0->setColumnStretch(1, 1);
     QLabel *audio_label = new QLabel("Audio:");
+    audio_label->setToolTip(
+            "<p>Choose the audio stream, from 1 to the number of "
+            "audio streams available in your input file(s).</p>");
     layout0->addWidget(audio_label, 0, 2);
     _audio_spinbox = new QSpinBox();
+    _audio_spinbox->setToolTip(audio_label->toolTip());
     _audio_spinbox->setRange(1, 999);
     _audio_spinbox->setValue(1);
     layout0->addWidget(_audio_spinbox, 0, 3);
     QLabel *output_label = new QLabel("Output:");
+    output_label->setToolTip(
+            "<p>Set the 3D output type for your display.</p>");
     QGridLayout *layout1 = new QGridLayout;
     layout1->addWidget(output_label, 1, 0);
     _output_combobox = new QComboBox(this);
+    _output_combobox->setToolTip(output_label->toolTip());
     _output_combobox->addItem("Left view");
     _output_combobox->addItem("Right view");
     _output_combobox->addItem("Top/bottom");
@@ -184,31 +194,51 @@ in_out_widget::in_out_widget(QSettings *settings, QWidget *parent)
     layout1->setColumnStretch(1, 1);
     QGridLayout *layout2 = new QGridLayout;
     _swap_eyes_button = new QPushButton("Swap eyes");
+    _swap_eyes_button->setToolTip(
+            "<p>Swap the left and right view. "
+            "Use this if the 3D effect seems wrong.</p>");
     _swap_eyes_button->setCheckable(true);
     connect(_swap_eyes_button, SIGNAL(toggled(bool)), this, SLOT(swap_eyes_changed()));
     layout2->addWidget(_swap_eyes_button, 0, 0, 1, 2);
     _fullscreen_button = new QPushButton("Fullscreen");
+    _fullscreen_button->setToolTip(
+            "<p>Switch to fullscreen mode. "
+            "You can leave fullscreen mode by pressing the f key.</p>");
     connect(_fullscreen_button, SIGNAL(pressed()), this, SLOT(fullscreen_pressed()));
     layout2->addWidget(_fullscreen_button, 0, 2, 1, 2);
     _center_button = new QPushButton("Center");
+    _center_button->setToolTip(
+            "<p>Center the video area on your screen.</p>");
     connect(_center_button, SIGNAL(pressed()), this, SLOT(center_pressed()));
     layout2->addWidget(_center_button, 0, 4, 1, 2);
+    layout2->addWidget(new QWidget(), 0, 6, 1, 1);
     _parallax_label = new QLabel("Parallax:");
-    layout2->addWidget(_parallax_label, 0, 6, 1, 1);
+    _parallax_label->setToolTip(
+            "<p>Adjust parallax, from -1 to +1. This changes the separation of left and right view, "
+            "and thus moves the point where both lines of sight meet.</p>");
+    layout2->addWidget(_parallax_label, 0, 7, 1, 1);
     _parallax_spinbox = new QDoubleSpinBox();
+    _parallax_spinbox->setToolTip(_parallax_label->toolTip());
     _parallax_spinbox->setRange(-1.0, +1.0);
     _parallax_spinbox->setValue(0);
     _parallax_spinbox->setDecimals(2);
     _parallax_spinbox->setSingleStep(0.01);
     connect(_parallax_spinbox, SIGNAL(valueChanged(double)), this, SLOT(parallax_changed()));
-    layout2->addWidget(_parallax_spinbox, 0, 7, 1, 1);
+    layout2->addWidget(_parallax_spinbox, 0, 8, 1, 1);
     _ghostbust_label = new QLabel("Ghostbusting:");
-    layout2->addWidget(_ghostbust_label, 0, 8, 1, 1);
+    _ghostbust_label->setToolTip(
+            "<p>Set the amount of crosstalk ghostbusting, from 0% to 100%. "
+            "You need to set the crosstalk levels of your display in the Preferences menu first. "
+            "Note that crosstalk ghostbusting does not work with anaglyph glasses.</p>");
+    layout2->addWidget(_ghostbust_label, 0, 9, 1, 1);
     _ghostbust_spinbox = new QSpinBox();
+    _ghostbust_spinbox->setToolTip(_ghostbust_label->toolTip());
+    _ghostbust_spinbox->setSuffix(" %");
     _ghostbust_spinbox->setRange(0, 100);
     _ghostbust_spinbox->setValue(0);
     connect(_ghostbust_spinbox, SIGNAL(valueChanged(int)), this, SLOT(ghostbust_changed()));
-    layout2->addWidget(_ghostbust_spinbox, 0, 9, 1, 1);
+    layout2->addWidget(_ghostbust_spinbox, 0, 10, 1, 1);
+    layout2->setColumnStretch(6, 1);
     layout2->setRowStretch(0, 1);
     QGridLayout *layout = new QGridLayout;
     layout->addLayout(layout0, 0, 0);
@@ -319,19 +349,15 @@ void in_out_widget::input_changed()
 {
     if (input::mode_is_2d(input_mode()) && !video_output::mode_is_2d(video_mode()))
     {
-        _settings->beginGroup("Session");
         QString fallback_mode_name = QString(video_output::mode_name(video_output::mono_left).c_str());
-        QString mode_name = _settings->value(QString("2d-output-mode"), fallback_mode_name).toString();
+        QString mode_name = _settings->value("Session/2d-output-mode", fallback_mode_name).toString();
         set_output(video_output::mode_from_name(mode_name.toStdString()));
-        _settings->endGroup();
     }
     else if (!input::mode_is_2d(input_mode()) && video_output::mode_is_2d(video_mode()))
     {
-        _settings->beginGroup("Session");
         QString fallback_mode_name = QString(video_output::mode_name(video_output::anaglyph_red_cyan_dubois).c_str());
-        QString mode_name = _settings->value(QString("3d-output-mode"), fallback_mode_name).toString();
+        QString mode_name = _settings->value("Session/3d-output-mode", fallback_mode_name).toString();
         set_output(video_output::mode_from_name(mode_name.toStdString()));
-        _settings->endGroup();
     }
 }
 
@@ -472,20 +498,10 @@ void in_out_widget::receive_notification(const notification &note)
         _swap_eyes_button->setEnabled(note.current.flag);
         _fullscreen_button->setEnabled(note.current.flag);
         _center_button->setEnabled(note.current.flag);
-        {
-            bool parallax = (note.current.flag && input_mode() != input::mono);
-            _parallax_label->setEnabled(parallax);
-            _parallax_spinbox->setEnabled(parallax);
-        }
-        {
-            bool ghostbust = (note.current.flag
-                    && video_mode() != video_output::anaglyph_red_cyan_dubois
-                    && video_mode() != video_output::anaglyph_red_cyan_monochrome
-                    && video_mode() != video_output::anaglyph_red_cyan_full_color
-                    && video_mode() != video_output::anaglyph_red_cyan_half_color);
-            _ghostbust_label->setEnabled(ghostbust);
-            _ghostbust_spinbox->setEnabled(ghostbust);
-        }
+        _parallax_label->setEnabled(note.current.flag);
+        _parallax_spinbox->setEnabled(note.current.flag);
+        _ghostbust_label->setEnabled(note.current.flag);
+        _ghostbust_spinbox->setEnabled(note.current.flag);
         break;
     case notification::swap_eyes:
         _lock = true;
@@ -494,18 +510,14 @@ void in_out_widget::receive_notification(const notification &note)
         break;
     case notification::parallax:
         _lock = true;
-        if (_parallax_spinbox->isEnabled())
-        {
-            _parallax_spinbox->setValue(note.current.value);
-        }
+        _parallax_spinbox->setValue(note.current.value);
         _lock = false;
+        break;
     case notification::ghostbust:
         _lock = true;
-        if (_ghostbust_spinbox->isEnabled())
-        {
-            _ghostbust_spinbox->setValue(qRound(note.current.value * 100.0f));
-        }
+        _ghostbust_spinbox->setValue(qRound(note.current.value * 100.0f));
         _lock = false;
+        break;
     default:
         break;
     }
@@ -517,36 +529,49 @@ controls_widget::controls_widget(QSettings *settings, QWidget *parent)
 {
     QGridLayout *layout = new QGridLayout;
     _seek_slider = new QSlider(Qt::Horizontal);
+    _seek_slider->setToolTip(
+            "<p>This slider shows the progress during video playback, "
+            "and can be used to seek in the video. Note that this may "
+            "not work with all videos.</p>");
     _seek_slider->setRange(0, 2000);
     _seek_slider->setTracking(false);
     connect(_seek_slider, SIGNAL(valueChanged(int)), this, SLOT(seek_slider_changed()));
     layout->addWidget(_seek_slider, 0, 0, 1, 10);
     _play_button = new QPushButton(QIcon(":icons/play.png"), "");
+    _play_button->setToolTip("<p>Play.</p>");
     connect(_play_button, SIGNAL(pressed()), this, SLOT(play_pressed()));
     layout->addWidget(_play_button, 1, 0);
     _pause_button = new QPushButton(QIcon(":icons/pause.png"), "");
+    _pause_button->setToolTip("<p>Pause.</p>");
     connect(_pause_button, SIGNAL(pressed()), this, SLOT(pause_pressed()));
     layout->addWidget(_pause_button, 1, 1);
     _stop_button = new QPushButton(QIcon(":icons/stop.png"), "");
+    _stop_button->setToolTip("<p>Stop.</p>");
     connect(_stop_button, SIGNAL(pressed()), this, SLOT(stop_pressed()));
     layout->addWidget(_stop_button, 1, 2);
     layout->addWidget(new QWidget, 1, 3);
     _bbb_button = new QPushButton(QIcon(":icons/bbb.png"), "");
+    _bbb_button->setToolTip("<p>Seek backward 10 minutes.</p>");
     connect(_bbb_button, SIGNAL(pressed()), this, SLOT(bbb_pressed()));
     layout->addWidget(_bbb_button, 1, 4);
     _bb_button = new QPushButton(QIcon(":icons/bb.png"), "");
+    _bb_button->setToolTip("<p>Seek backward 1 minute.</p>");
     connect(_bb_button, SIGNAL(pressed()), this, SLOT(bb_pressed()));
     layout->addWidget(_bb_button, 1, 5);
     _b_button = new QPushButton(QIcon(":icons/b.png"), "");
+    _b_button->setToolTip("<p>Seek backward 10 seconds.</p>");
     connect(_b_button, SIGNAL(pressed()), this, SLOT(b_pressed()));
     layout->addWidget(_b_button, 1, 6);
     _f_button = new QPushButton(QIcon(":icons/f.png"), "");
+    _f_button->setToolTip("<p>Seek forward 10 seconds.</p>");
     connect(_f_button, SIGNAL(pressed()), this, SLOT(f_pressed()));
     layout->addWidget(_f_button, 1, 7);
     _ff_button = new QPushButton(QIcon(":icons/ff.png"), "");
+    _ff_button->setToolTip("<p>Seek forward 1 minute.</p>");
     connect(_ff_button, SIGNAL(pressed()), this, SLOT(ff_pressed()));
     layout->addWidget(_ff_button, 1, 8);
     _fff_button = new QPushButton(QIcon(":icons/fff.png"), "");
+    _fff_button->setToolTip("<p>Seek forward 10 minutes.</p>");
     connect(_fff_button, SIGNAL(pressed()), this, SLOT(fff_pressed()));
     layout->addWidget(_fff_button, 1, 9);
     layout->setRowStretch(0, 0);
@@ -758,6 +783,8 @@ main_window::main_window(QSettings *settings, const player_init_data &init_data)
 
     // Handle FileOpen events
     QApplication::instance()->installEventFilter(this);
+    // Handle Drop events
+    setAcceptDrops(true);
 
     show();     // Must happen before opening initial files!
     raise();
@@ -833,24 +860,22 @@ void main_window::receive_notification(const notification &note)
                 _stop_request = true;
             }
             // Remember the input settings of this video, using an SHA1 hash of its filename.
-            _settings->beginGroup("Video");
+            _settings->beginGroup("Video/" + current_file_hash());
             if (_init_data.filenames.size() == 1)
             {
-                _settings->setValue(current_file_hash(), QString(input::mode_name(_init_data.input_mode).c_str()));
+                _settings->setValue("input-mode", QString(input::mode_name(_init_data.input_mode).c_str()));
             }
-            _settings->setValue(current_file_hash() + "-audio-stream", QVariant(_init_data.audio_stream + 1).toString());
+            _settings->setValue("audio-stream", QVariant(_init_data.audio_stream + 1).toString());
             _settings->endGroup();
             // Remember the 2D or 3D video output mode.
-            _settings->beginGroup("Session");
             if (_init_data.input_mode == input::mono)
             {
-                _settings->setValue("2d-output-mode", QString(video_output::mode_name(_init_data.video_mode).c_str()));
+                _settings->setValue("Session/2d-output-mode", QString(video_output::mode_name(_init_data.video_mode).c_str()));
             }
             else
             {
-                _settings->setValue("3d-output-mode", QString(video_output::mode_name(_init_data.video_mode).c_str()));
+                _settings->setValue("Session/3d-output-mode", QString(video_output::mode_name(_init_data.video_mode).c_str()));
             }
-            _settings->endGroup();
             // Update widgets: we're now playing
             _in_out_widget->update(_init_data, true, true);
             _controls_widget->update(_init_data, true, true);
@@ -884,26 +909,56 @@ void main_window::receive_notification(const notification &note)
     else if (note.type == notification::swap_eyes)
     {
         _init_data.video_state.swap_eyes = note.current.flag;
-        _settings->beginGroup("Video");
-        _settings->setValue(current_file_hash() + "-swap-eyes", QVariant(_init_data.video_state.swap_eyes).toString());
+        _settings->beginGroup("Video/" + current_file_hash());
+        _settings->setValue("swap-eyes", QVariant(_init_data.video_state.swap_eyes).toString());
         _settings->endGroup();
     }
     else if (note.type == notification::parallax)
     {
         _init_data.video_state.parallax = note.current.value;
-        _settings->beginGroup("Video");
-        _settings->setValue(current_file_hash() + "-parallax", QVariant(_init_data.video_state.parallax).toString());
+        _settings->beginGroup("Video/" + current_file_hash());
+        _settings->setValue("parallax", QVariant(_init_data.video_state.parallax).toString());
         _settings->endGroup();
     }
     else if (note.type == notification::ghostbust)
     {
         _init_data.video_state.ghostbust = note.current.value;
-        _settings->beginGroup("Video");
-        _settings->setValue(current_file_hash() + "-ghostbust", QVariant(_init_data.video_state.ghostbust).toString());
+        _settings->beginGroup("Video/" + current_file_hash());
+        _settings->setValue("ghostbust", QVariant(_init_data.video_state.ghostbust).toString());
         _settings->endGroup();
     }
 }
 
+void main_window::dragEnterEvent(QDragEnterEvent *event)
+{
+    if (event->mimeData()->hasUrls())
+    {
+        event->acceptProposedAction();
+    }
+}
+
+void main_window::dropEvent(QDropEvent *event)
+{
+    if (event->mimeData()->hasUrls())
+    {
+        QList<QUrl> url_list = event->mimeData()->urls();
+        if (url_list.size() > 3)
+        {
+            QMessageBox::critical(this, "Error", "Cannot open more than 3 files");
+        }
+        else
+        {
+            QStringList urls;
+            for (int i = 0; i < url_list.size(); i++)
+            {
+                urls.append(url_list[i].toString());
+            }
+            open(urls, true);
+            event->acceptProposedAction();
+        }
+    }
+}
+
 void main_window::moveEvent(QMoveEvent *)
 {
     move_event();
@@ -920,6 +975,20 @@ void main_window::closeEvent(QCloseEvent *event)
     event->accept();
 }
 
+bool main_window::eventFilter(QObject *obj, QEvent *event)
+{
+    if (event->type() == QEvent::FileOpen)
+    {
+        open(QStringList(static_cast<QFileOpenEvent *>(event)->file()), true);
+        return true;
+    }
+    else
+    {
+        // pass the event on to the parent class
+        return QMainWindow::eventFilter(obj, event);
+    }
+}
+
 void main_window::move_event()
 {
     if (_player)
@@ -959,35 +1028,34 @@ void main_window::open(QStringList filenames, bool automatic)
     }
     if (open_player())
     {
-        _settings->beginGroup("Video");
+        _settings->beginGroup("Video/" + current_file_hash());
         if (_init_data.filenames.size() == 1)
         {
             QString fallback_mode_name = QString(input::mode_name(_player->input_mode()).c_str());
-            QString mode_name = _settings->value(current_file_hash(), fallback_mode_name).toString();
+            QString mode_name = _settings->value("input-mode", fallback_mode_name).toString();
             _init_data.input_mode = input::mode_from_name(mode_name.toStdString());
         }
         else
         {
             _init_data.input_mode = _player->input_mode();
         }
-        _init_data.audio_stream = QVariant(_settings->value(current_file_hash() + "-audio-stream", QString("1")).toString()).toInt() - 1;
-        _init_data.video_state.swap_eyes = QVariant(_settings->value(current_file_hash() + "-swap-eyes", QString("false")).toString()).toBool();
-        _init_data.video_state.parallax = QVariant(_settings->value(current_file_hash() + "-parallax", QString("0")).toString()).toFloat();
-        _init_data.video_state.ghostbust = QVariant(_settings->value(current_file_hash() + "-ghostbust", QString("0")).toString()).toFloat();
+        _init_data.audio_stream = QVariant(_settings->value("audio-stream", QString("1")).toString()).toInt() - 1;
+        _init_data.video_state.swap_eyes = QVariant(_settings->value("swap-eyes", QString("false")).toString()).toBool();
+        _init_data.video_state.parallax = QVariant(_settings->value("parallax", QString("0")).toString()).toFloat();
+        _init_data.video_state.ghostbust = QVariant(_settings->value("ghostbust", QString("0")).toString()).toFloat();
         _settings->endGroup();
-        _settings->beginGroup("Session");
         if (automatic)
         {
             if (_init_data.input_mode == input::mono)
             {
                 QString fallback_mode_name = QString(video_output::mode_name(video_output::mono_left).c_str());
-                QString mode_name = _settings->value(QString("2d-output-mode"), fallback_mode_name).toString();
+                QString mode_name = _settings->value("Session/2d-output-mode", fallback_mode_name).toString();
                 _init_data.video_mode = video_output::mode_from_name(mode_name.toStdString());
             }
             else
             {
                 QString fallback_mode_name = QString(video_output::mode_name(video_output::anaglyph_red_cyan_dubois).c_str());
-                QString mode_name = _settings->value(QString("3d-output-mode"), fallback_mode_name).toString();
+                QString mode_name = _settings->value("Session/3d-output-mode", fallback_mode_name).toString();
                 _init_data.video_mode = video_output::mode_from_name(mode_name.toStdString());
             }
         }
@@ -995,7 +1063,6 @@ void main_window::open(QStringList filenames, bool automatic)
         {
             _init_data.video_mode = _player->video_mode();
         }
-        _settings->endGroup();
         _in_out_widget->update(_init_data, true, false);
         _controls_widget->update(_init_data, true, false);
     }
@@ -1009,9 +1076,7 @@ void main_window::open(QStringList filenames, bool automatic)
 void main_window::file_open()
 {
     QFileDialog *file_dialog = new QFileDialog(this);
-    _settings->beginGroup("Session");
-    file_dialog->setDirectory(_settings->value("file-open-dir", QDir::currentPath()).toString());
-    _settings->endGroup();
+    file_dialog->setDirectory(_settings->value("Session/file-open-dir", QDir::currentPath()).toString());
     file_dialog->setWindowTitle("Open up to three files");
     file_dialog->setAcceptMode(QFileDialog::AcceptOpen);
     file_dialog->setFileMode(QFileDialog::ExistingFiles);
@@ -1029,9 +1094,7 @@ void main_window::file_open()
         QMessageBox::critical(this, "Error", "Cannot open more than 3 files");
         return;
     }
-    _settings->beginGroup("Session");
-    _settings->setValue("file-open-dir", file_dialog->directory().path());
-    _settings->endGroup();
+    _settings->setValue("Session/file-open-dir", file_dialog->directory().path());
     open(file_names, true);
 }
 
@@ -1077,18 +1140,21 @@ void main_window::preferences_crosstalk()
     layout->addWidget(red_label, 1, 0, 1, 2);
     QSpinBox *red_spinbox = new QSpinBox();
     red_spinbox->setRange(0, 100);
+    red_spinbox->setSuffix(" %");
     red_spinbox->setValue(_init_data.video_state.crosstalk_r * 100.0f);
     layout->addWidget(red_spinbox, 1, 2, 1, 4);
     QLabel *green_label = new QLabel("Green:");
     layout->addWidget(green_label, 2, 0, 1, 3);
     QSpinBox *green_spinbox = new QSpinBox();
     green_spinbox->setRange(0, 100);
+    green_spinbox->setSuffix(" %");
     green_spinbox->setValue(_init_data.video_state.crosstalk_g * 100.0f);
     layout->addWidget(green_spinbox, 2, 2, 1, 4);
     QLabel *blue_label = new QLabel("Blue:");
     layout->addWidget(blue_label, 3, 0, 1, 2);
     QSpinBox *blue_spinbox = new QSpinBox();
     blue_spinbox->setRange(0, 100);
+    blue_spinbox->setSuffix(" %");
     blue_spinbox->setValue(_init_data.video_state.crosstalk_b * 100.0f);
     layout->addWidget(blue_spinbox, 3, 2, 1, 4);
     QPushButton *ok_button = new QPushButton(tr("&OK"));
@@ -1136,7 +1202,8 @@ void main_window::help_website()
 void main_window::help_keyboard()
 {
     QMessageBox::information(this, tr("Keyboard Shortcuts"), tr(
-                "<p>Keyboard control:"
+                "<p>Keyboard control:<br>"
+                "(Click into the video area to give it the keyboard focus if necessary.)"
                 "<table>"
                 "<tr><td>q or ESC</td><td>Stop</td></tr>"
                 "<tr><td>p or SPACE</td><td>Pause / unpause</td></tr>"
@@ -1147,15 +1214,12 @@ void main_window::help_keyboard()
                 "<tr><td>3, 4</td><td>Adjust brightness</td></tr>"
                 "<tr><td>5, 6</td><td>Adjust hue</td></tr>"
                 "<tr><td>7, 8</td><td>Adjust saturation</td></tr>"
-                "<tr><td><, ></td><td>Adjust parallax</td></tr>"
+                "<tr><td>&lt;, &gt;</td><td>Adjust parallax</td></tr>"
                 "<tr><td>(, )</td><td>Adjust ghostbusting</td></tr>"
                 "<tr><td>left, right</td><td>Seek 10 seconds backward / forward</td></tr>"
                 "<tr><td>up, down</td><td>Seek 1 minute backward / forward</td></tr>"
                 "<tr><td>page up, page down</td><td>Seek 10 minutes backward / forward</td></tr>"
                 "</table>"
-                "</p>"
-                "<p>"
-                "(Click into the video area to give it the keyboard focus if necessary.)"
                 "</p>"));
 }
 
@@ -1181,20 +1245,6 @@ void main_window::help_about()
     QMessageBox::about(this, tr("About " PACKAGE_NAME), blurb);
 }
 
-bool main_window::eventFilter(QObject *obj, QEvent *event)
-{
-    if (event->type() == QEvent::FileOpen)
-    {
-        open(QStringList(static_cast<QFileOpenEvent *>(event)->file()), true);
-        return true;
-    }
-    else
-    {
-        // pass the event on to the parent class
-        return QMainWindow::eventFilter(obj, event);
-    }
-}
-
 player_qt::player_qt() : player(player::slave)
 {
     _qt_app_owner = init_qt();
