@@ -32,7 +32,7 @@
 #include "msg.h"
 #include "str.h"
 #include "timer.h"
-#include "debug.h"
+#include "dbg.h"
 
 #include "video_output_opengl.h"
 #include "video_output_opengl_color.fs.glsl.h"
@@ -440,7 +440,7 @@ static void draw_quad(float x, float y, float w, float h)
     glEnd();
 }
 
-void video_output_opengl::display(bool toggle_swap_eyes, float x, float y, float w, float h, const int viewport[4])
+void video_output_opengl::display(bool mono_right_instead_of_left, float x, float y, float w, float h, const int viewport[4])
 {
     clear();
     if (!_have_valid_data[_active_tex_set])
@@ -456,10 +456,6 @@ void video_output_opengl::display(bool toggle_swap_eyes, float x, float y, float
     {
         std::swap(left, right);
     }
-    if (toggle_swap_eyes)
-    {
-        std::swap(left, right);
-    }
     if ((_mode == even_odd_rows || _mode == checkerboard) && (screen_pos_y() + viewport[1]) % 2 == 0)
     {
         std::swap(left, right);
@@ -623,12 +619,12 @@ void video_output_opengl::display(bool toggle_swap_eyes, float x, float y, float
     {
         draw_quad(x, y, w, h);
     }
-    else if (_mode == mono_left)
+    else if (_mode == mono_left && !mono_right_instead_of_left)
     {
         glUniform1f(glGetUniformLocation(_render_prg, "channel"), 0.0f);
         draw_quad(x, y, w, h);
     }
-    else if (_mode == mono_right)
+    else if (_mode == mono_right || (_mode == mono_left && mono_right_instead_of_left))
     {
         glUniform1f(glGetUniformLocation(_render_prg, "channel"), 1.0f);
         draw_quad(x, y, w, h);
@@ -733,15 +729,10 @@ void *video_output_opengl::prepare_start(int /* view */, int plane)
     void *pboptr = glMapBuffer(GL_PIXEL_UNPACK_BUFFER, GL_WRITE_ONLY);
     if (!pboptr)
     {
-        debug::oom_abort();
-    }
-    if (reinterpret_cast<uintptr_t>(pboptr) % 4 != 0)
-    {
-        // We can assume that the buffer is always at least aligned at a 4-byte boundary.
-        // This is just a sanity check; this error should never be triggered.
-        msg::err("pixel buffer alignment is less than 4!");
-        debug::crash();
+        dbg::oom_abort();
     }
+    // We can assume that the buffer is always at least aligned at a 4-byte boundary.
+    assert(reinterpret_cast<uintptr_t>(pboptr) % 4 == 0);
     return pboptr;
 }
 
